create_treemap_figure

create_treemap_figure(data)

Transforms the flat list into a Plotly Treemap object.

Parameters

Name Type Description Default
data list of dict The list of dictionaries representing files and folders with their sizes and hierarchy. required

Returns

Name Type Description
plotly.graph_objects.Figure A Plotly Treemap figure representing the directory structure.

Examples

>>> fig = create_treemap_figure([{"id": "root", "name": "root", "parent": "", "value": 0}])
>>> fig.__class__.__name__
'Figure'