visualize_dir

visualize_dir(path=".")

Main function to visualize the directory.

Parameters

Name Type Description Default
path str The root directory path from which to start visualizing the directory. "."

Returns

Name Type Description
plotly.graph_objects.Figure A Plotly Treemap figure representing the directory structure.

Examples

>>> fig = visualize_dir(".")
>>> fig.__class__.__name__
'Figure'