Function reference
tame_your_files
Pure, non-destructive filesystem analysis utilities.
| FileInfo | Container for file metadata. |
| files_to_free_space | Determine the minimum number of files that would need to be deleted |
| largest_files | Recursively scan a directory and return the n largest files. |
| find_duplicates_by_content | Finds duplicate files based on file content (MD5 hash) within a given directory and its subdirectories. |
| find_duplicates_by_name | Finds duplicate files based on file names within a given directory and its subdirectories. |
| find_duplicates_by_size | Finds duplicate files based on file sizes within a given directory and its subdirectories. |
| create_treemap_figure | Transforms the flat list into a Plotly Treemap object. |
| get_directory_data | Walks the directory and builds a representative list of dictionaries of all children. Uses os.walk to capture every file and folder. |